/***********************************************************************
      PACKAGE: ANSI/NIST 2000 Standard Reference Implementation

      FILE:    AN2K.H

      AUTHORS: Michael D. Garris
      DATE:    03/28/2000

***********************************************************************/
#ifndef _AN2K_H
#define _AN2K_H

#include <stdio.h>  /* Needed for references to (FILE *) below */
/* characters in items */
typedef struct item{
   int num_bytes;   /* Always contains the current byte size of the entire */
                    /* item including any trailing US separator.           */
   int num_chars;   /* Number of characters currently in value, NOT  */
                    /* including the NULL terminator.                */
   int alloc_chars; /* Number of allocated characters for the value, */
                    /* including the NULL terminator.                */
   unsigned char *value;  /* Must keep NULL terminated.              */
   int us_char;
} ITEM;

/* items in subfields */
typedef struct subfield{
   int num_bytes;
   int num_items;
   int alloc_items;
   ITEM **items;
   int rs_char;
} SUBFIELD;

/* subfields in fields */
typedef struct field{
   char *id;
   unsigned int record_type;
   unsigned int field_int;
   int num_bytes;
   int num_subfields;
   int alloc_subfields;
   SUBFIELD **subfields;
   int gs_char;
} FIELD;

/* fields in records */
typedef struct record{
   unsigned int type;
   int total_bytes;
   int num_bytes;
   int num_fields;
   int alloc_fields;
   FIELD **fields;
   int fs_char;
} RECORD;

/* records in ANSI_NIST file */
typedef struct ansi_nist{
   unsigned int version;
   int num_bytes;
   int num_records;
   int alloc_records;
   RECORD **records;
} ANSI_NIST;

#define ANSI_NIST_CHUNK   100
#ifndef TRUE
#define TRUE              1
#define FALSE             0
#endif
#define UNSET             -1
#define DONE              2
#define MORE              3
#define UNDEFINED_INT     -1
#ifndef IGNORE
#define IGNORE            2
#endif

#define TYPE_1_ID         1
#define TYPE_1_NUM_MANDITORY_FIELDS 9
#define TYPE_2_ID         2
#define TYPE_3_ID         3
#define TYPE_4_ID         4
#define TYPE_5_ID         5
#define TYPE_6_ID         6
#define TYPE_7_ID         7
#define TYPE_8_ID         8
#define TYPE_9_ID         9
#define TYPE_10_ID       10
#define TYPE_11_ID       11
#define TYPE_12_ID       12
#define TYPE_13_ID       13
#define TYPE_14_ID       14
#define TYPE_15_ID       15
#define TYPE_16_ID       16

/* Type-1 Field IDs */
#define LEN_ID            1
#define VER_ID            2
#define CNT_ID            3
#define DAT_ID            5
#define ORI_ID            8
#define NTR_ID           12
#define DCS_ID           15

#define IDC_FMT           "%02d"
#define FLD_FMT           "%d.%03d:"
#define ASCII_CSID        0

#define VERSION_0200      200
#define VERSION_0300      300

#define FS_CHAR           0x1C
#define GS_CHAR           0x1D
#define RS_CHAR           0x1E
#define US_CHAR           0x1F

extern unsigned int tagged_records[];
#define NUM_TAGGED_RECORDS           8

extern unsigned int binary_records[];
#define NUM_BINARY_RECORDS           6

extern unsigned int tagged_image_records[];
#define NUM_TAGGED_IMAGE_RECORDS     5
#define IMAGE_FIELD                999

extern unsigned int binary_image_records[];
#define NUM_BINARY_IMAGE_RECORDS     4
#define BINARY_LEN_BYTES             4
#define BINARY_IDC_BYTES             1
#define BINARY_IMP_BYTES             1
#define BINARY_FGP_BYTES             6
#define BINARY_ISR_BYTES             1
#define BINARY_HLL_BYTES             2
#define BINARY_VLL_BYTES             2
#define BINARY_CA_BYTES              1
#define NUM_BINARY_IMAGE_FIELDS      9

/* Type-3,4,5,6 Field IDs */
/* LEN_ID       1 defined above */
#define IDC_ID                       2
#define IMP_ID                       3
#define FGP_ID                       4
#define ISR_ID                       5
#define HLL_ID                       6
#define VLL_ID                       7
#define BIN_CA_ID                    8
#define BIN_IMAGE_ID                 9

extern unsigned int binary_signature_records[];
#define NUM_BINARY_SIGNATURE_RECORDS 1
#define BINARY_SIG_BYTES             1
#define BINARY_SRT_BYTES             1
#define NUM_BINARY_SIGNATURE_FIELDS  8

/* Type-8 Field IDs */
/* LEN_ID       1 defined above */
/* IDC_ID       2 defined above */
#define SIG_ID                       3
#define SRT_ID                       4
/* ISR_ID       5 defined above */
/* HLL_ID       6 defined above */
/* VLL_ID       7 defined above */

/* Type-10,13,14,15,16 Field IDs */
/* LEN_ID       1 defined above */
/* IDC_ID       2 defined above */
/* IMP_ID       3 defined above */
#define SRC_ID                        4
#define CD_ID                         5
/* HLL_ID       6 defined above */
/* VLL_ID       7 defined above */
#define SLC_ID                        8
#define HPS_ID                        9
#define VPS_ID                       10
#define TAG_CA_ID                    11
#define CSP_ID                       12
#define BPX_ID                       12
#define FGP3_ID                      13
#define DAT2_ID             IMAGE_FIELD

/* Type-9 Standard Field IDs */
/* LEN_ID       1 defined above */
/* IDC_ID       2 defined above */
/* IMP_ID       3 defined above */
#define FMT_ID                        4
#define OFR_ID                        5
#define FGP2_ID                       6
#define FPC_ID                        7
#define CRP_ID                        8
#define DLT_ID                        9
#define MIN_ID                       10
#define RDG_ID                       11
#define MRC_ID                       12
/* Type-9 FBI/IAFIS Field IDs  */
/* EFTS Field 13 Non-standard! */
#define FGN_ID                       14
#define NMN_ID                       15
#define FCP_ID                       16
#define APC_ID                       17
#define ROV_ID                       18
#define COF_ID                       19
#define ORN_ID                       20
#define CRA_ID                       21
#define DLA_ID                       22
#define MAT_ID                       23

/* Maximum number of minutiae in an FBI/IAFIS Type-9 record. */
#define MAX_IAFIS_MINUTIAE          254
/* Maximum number of pattern classes in an FBI/IAFIS Type-9 record. */
#define MAX_IAFIS_PATTERN_CLASSES     3
/* Maximum number of cores in an FBI/IAFIS Type-9 record. */
#define MAX_IAFIS_CORES               2
/* Maximum number of deltas in an FBI/IAFIS Type-9 record. */
#define MAX_IAFIS_DELTAS              2
/* Maximum number of items in FBI/IAFIS minutia subfield. */
#define MAX_IAFIS_MINUTIA_ITEMS      13
/* Number of characters in an FBI/IAFIS method string. */
#define IAFIS_METHOD_STRLEN           3

/* Minimum Table 5 Impression Code. */
#define MIN_TABLE_5_CODE              0
/* Maximum Table 5 Impression Code. */
#define MAX_TABLE_5_CODE              7

/* Minimum Table 6 Finger Position Code. */
#define MIN_TABLE_6_CODE              0
/* Maximum Table 6 Finger Position Code. */
#define MAX_TABLE_6_CODE             14

/* Minimum Table 19 Palm Code. */
#define MIN_TABLE_19_CODE            20
/* Maximum Table 19 Palm Code. */
#define MAX_TABLE_19_CODE            30

/* Minimum Minutia Quality value. */
#define MIN_QUALITY_VALUE             0
/* Maximum Minutia Quality value. */
#define MAX_QUALITY_VALUE            63

/* Minimum scanning resolution in pixels/mm (500 dpi). */
#define MIN_RESOLUTION               19.69
/* Minimum scanning resolution in as stored in tagged field images. */
#define MIN_TAGGED_RESOLUTION        19.7
/* Scan resolution tolerance in mm's. */
#define MM_TOLERANCE                  0.2

#define FIELD_NUM_LEN              9
#define ITEM_START                 '='
#define ITEM_END                   US_CHAR

#define STD_STR                    "S"
#define USER_STR                   "U"
#define TBL_STR                    "T"
#define AUTO_STR                   "A"
#define PPI_STR                    "1"
#define PP_CM                      "2"

#define DEL_OP                     'd'
#define INS_OP                     'i'
#define PRN_OP                     'p'
#define SUB_OP                     's'

#define DEFAULT_FPOUT              stdout

#ifndef MAX_UINT_CHARS
#define MAX_UINT_CHARS   10
#define MAX_USHORT_CHARS  5
#endif

#define UNUSED_STR                 "255"

#define MM_PER_INCH                 25.4

#define UNKNOWN_HAND                 0
#define RIGHT_HAND                   1
#define LEFT_HAND                    2

#define COMP_NONE                  "NONE"
#define BIN_COMP_NONE              "0"
#define COMP_WSQ                   "WSQ20"
#define BIN_COMP_WSQ               "1"
#define COMP_JPEGB                 "JPEGB"
#define BIN_COMP_JPEGB             "2"
#define COMP_JPEGL                 "JPEGL"
/* #define BIN_COMP_JPEGL          <not defined> */
#define CSP_GRAY                   "GRAY"
#define CSP_RGB                    "RGB"
#define CSP_YCC                    "YCC"

/***********************************************************************/
/* ALLOC.C : ALLOCATION ROUTINES */
extern int alloc_ANSI_NIST(ANSI_NIST **);
extern int new_ANSI_NIST_record(RECORD **, const int);
extern int alloc_ANSI_NIST_record(RECORD **);
extern int new_ANSI_NIST_field(FIELD **, const int, const int);
extern int alloc_ANSI_NIST_field(FIELD **);
extern int alloc_ANSI_NIST_subfield(SUBFIELD **);
extern int alloc_ANSI_NIST_item(ITEM **);
extern void free_ANSI_NIST(ANSI_NIST *);
extern void free_ANSI_NIST_record(RECORD *);
extern void free_ANSI_NIST_field(FIELD *);
extern void free_ANSI_NIST_subfield(SUBFIELD *);
extern void free_ANSI_NIST_item(ITEM *);

/***********************************************************************/
/* APPEND.C : APPEND ROUTINES */
extern int append_ANSI_NIST_record(RECORD *, FIELD *);
extern int append_ANSI_NIST_field(FIELD *, SUBFIELD *);
extern int append_ANSI_NIST_subfield(SUBFIELD *, ITEM *);

/***********************************************************************/
/* COPY.C : COPY ROUTINES */
extern int copy_ANSI_NIST(ANSI_NIST **, ANSI_NIST *);
extern int copy_ANSI_NIST_record(RECORD **, RECORD *);
extern int copy_ANSI_NIST_field(FIELD **, FIELD *);
extern int copy_ANSI_NIST_subfield(SUBFIELD **, SUBFIELD *);
extern int copy_ANSI_NIST_item(ITEM **, ITEM *);

/***********************************************************************/
/* DATE.C : DATE ROUTINES */
extern int get_ANSI_NIST_date(char **);

/***********************************************************************/
/* DECODE.C : IMAGE RECORD DECODER ROUTINES */
extern int decode_ANSI_NIST_image(unsigned char **, int *, int *, int *,
                     double *, const ANSI_NIST *, const int, const int);
extern int decode_binary_field_image(unsigned char **, int *, int *, int *,
                     double *, const ANSI_NIST *, const int);
extern int decode_tagged_field_image(unsigned char **, int *, int *, int *,
                     double *, const ANSI_NIST *, const int, const int);

/***********************************************************************/
/* DELETE.C : DELETE ROUTINES */
extern int do_delete(const char *, const int, const int, const int,
              const int, ANSI_NIST *);
extern int delete_ANSI_NIST_select(const int, const int, const int,
              const int, ANSI_NIST *);
extern int delete_ANSI_NIST_record(const int, ANSI_NIST *);
extern int adjust_delrec_CNT_IDCs(const int, ANSI_NIST *);
extern int delete_ANSI_NIST_field(const int, const int, ANSI_NIST *);
extern int delete_ANSI_NIST_subfield(const int, const int, const int,
              ANSI_NIST *);
extern int delete_ANSI_NIST_item(const int, const int, const int,
              const int, ANSI_NIST *);

/***********************************************************************/
/* FLIP.C : FLIP COORDS & DIRECTION ROUTINES */
extern int flip_y_coord(char *, const int, const int, const double);
extern int flip_direction(char *, const int);

/***********************************************************************/
/* FMTSTD.C : ANSI_NIST FORMAT READ ROUTINES */
extern int read_ANSI_NIST_file(const char *, ANSI_NIST **);
extern int read_ANSI_NIST(FILE *, ANSI_NIST *);
extern int read_Type1_record(FILE *, RECORD **, unsigned int *);
extern int read_ANSI_NIST_remaining_records(FILE *, ANSI_NIST *);
extern int read_ANSI_NIST_record(FILE *, RECORD **, const unsigned int);
extern int read_ANSI_NIST_tagged_record(FILE *, RECORD **,
              const unsigned int);
extern int read_ANSI_NIST_record_length(FILE *, int *, FIELD **);
extern int read_ANSI_NIST_version(FILE *, int *, FIELD **);
extern int read_ANSI_NIST_integer_field(FILE *, int *, FIELD **);
extern int read_ANSI_NIST_remaining_fields(FILE *, RECORD *);
extern int read_ANSI_NIST_field(FILE *, FIELD **, int);
extern int read_ANSI_NIST_binary_image_field(FILE *, FIELD **, char *,
              const int, const int, int);
extern int read_ANSI_NIST_tagged_field(FILE *, FIELD **, char *, const int,
              const int, int);
extern int read_ANSI_NIST_field_ID(FILE *, char **, unsigned int *,
              unsigned int *);
extern int read_ANSI_NIST_subfield(FILE *, SUBFIELD **);
extern int read_ANSI_NIST_item(FILE *, ITEM **);
extern int read_ANSI_NIST_binary_image_record(FILE *, RECORD **,
              const unsigned int);
extern int read_ANSI_NIST_binary_signature_record(FILE *, RECORD **,
              const unsigned int);
extern int read_ANSI_NIST_binary_field(FILE *, FIELD **, const int);
/***********************************************************************/
/* FMTSTD.C : ANSI_NIST FORMAT WRITE ROUTINES */
extern int write_ANSI_NIST_file(const char *, const ANSI_NIST *);
extern int write_ANSI_NIST(FILE *, const ANSI_NIST *);
extern int write_ANSI_NIST_record(FILE *, RECORD *);
extern int write_ANSI_NIST_tagged_field(FILE *, const FIELD *);
extern int write_ANSI_NIST_tagged_subfield(FILE *, const SUBFIELD *);
extern int write_ANSI_NIST_tagged_item(FILE *, const ITEM *);
extern int write_ANSI_NIST_separator(FILE *, const char);
extern int write_ANSI_NIST_binary_field(FILE *, const FIELD *);
extern int write_ANSI_NIST_binary_subfield(FILE *, const SUBFIELD *);
extern int write_ANSI_NIST_binary_item(FILE *, const ITEM *);

/***********************************************************************/
/* FMTTEXT.C : READ FORMATTED TEXT ROUTINES */
extern int read_fmttext_file(const char *, ANSI_NIST **);
extern int read_fmttext(FILE *, ANSI_NIST *);
extern int read_fmttext_item(FILE *, int *, int *, int *, int *, int *,
              int *, char **);
/* FMTTEXT.C : WRITE FORMATTED TEXT ROUTINES */
extern int write_fmttext_file(const char *, const ANSI_NIST *);
extern int write_fmttext(FILE *, const ANSI_NIST *);
extern int write_fmttext_record(FILE *, const int, const ANSI_NIST *);
extern int write_fmttext_field(FILE *, const int, const int,
              const ANSI_NIST *);
extern int write_fmttext_image_field(FILE *, const int, const int,
                      const ANSI_NIST *);
extern int write_fmttext_subfield(FILE *, const int, const int, const int,
              const ANSI_NIST *);
extern int write_fmttext_item(FILE *, const int, const int, const int,
              const int, const ANSI_NIST *);

/***********************************************************************/
/* INSERT.C : INSERT ROUTINES */
extern int do_insert(const char *, const int, const int, const int,
              const int, const char *, ANSI_NIST *);
extern int insert_ANSI_NIST_select(const int, const int, const int,
              const int, const char *, ANSI_NIST *);
extern int insert_ANSI_NIST_record(const int, const char *, ANSI_NIST *);
extern int insert_ANSI_NIST_record_frmem(const int, RECORD *, ANSI_NIST *);
extern int adjust_insrec_CNT_IDCs(const int, ANSI_NIST *);
extern int insert_ANSI_NIST_field(const int, const int, const char *,
              ANSI_NIST *ansi_nist);
extern int insert_ANSI_NIST_subfield(const int, const int, const int,
              const char *, ANSI_NIST *);
extern int insert_ANSI_NIST_item(const int, const int, const int, const int,
              const char *, ANSI_NIST *);

/***********************************************************************/
/* LOOKUP.C : LOOKUP ROUTINES */
extern int lookup_ANSI_NIST_field(FIELD **, int *, const unsigned int,
              RECORD *);
extern int lookup_ANSI_NIST_subfield(SUBFIELD **, const unsigned int,
              FIELD *);
extern int lookup_ANSI_NIST_item(ITEM **, const unsigned int, SUBFIELD *);
extern int lookup_ANSI_NIST_image(RECORD **, int *, const int,
              const ANSI_NIST *);
extern int lookup_ANSI_NIST_image_ppmm(double *, ANSI_NIST *, const int);
extern int lookup_binary_field_image_ppmm(double *, const ANSI_NIST *,
              const int );
extern int lookup_tagged_field_image_ppmm(double *, RECORD *);
extern int lookup_ANSI_NIST_fingerprint(RECORD **, int *, const int,
              const ANSI_NIST *);
extern int lookup_binary_field_fingerprint(RECORD **, int *, const int,
              const ANSI_NIST *);
extern int lookup_tagged_field_fingerprint(RECORD **, int *, const int,
              const ANSI_NIST *);
extern int lookup_fingerprint_with_IDC(RECORD **, int *, const int, const int,
              const ANSI_NIST *);

/***********************************************************************/
/* PRINT.C : PRINT ROUTINES */
extern int do_print(const char *, const int, const int, const int,
              const int, ANSI_NIST *);
extern int print_ANSI_NIST_select(FILE *, const int, const int, const int,
              const int, ANSI_NIST *);

/***********************************************************************/
/* READ.C : GENERAL READ UTILITIES */
extern int read_binary_item_data(FILE *, unsigned char **, const int);
extern int read_binary_uint(FILE *, unsigned int *);
extern int read_binary_ushort(FILE *, unsigned short *);
extern int read_binary_uchar(FILE *, unsigned char *);
extern int read_binary_image_data(const char *, unsigned char **, int *);
extern int read_char(FILE *, const int);
extern int read_string(FILE *, char **, const int);
extern int read_integer(FILE *, int *, const int);
extern int skip_white_space(FILE *);

/***********************************************************************/
/* SIZE.C : FIELD BYTE SIZES */
extern int binary_image_field_bytes(const int);
extern int binary_signature_field_bytes(const int);

/***********************************************************************/
/* SUBSTITUTE.C : SUBSTITUTE ROUTINES */
extern int do_substitute(const char *, const int, const int, const int,
              const int, const char *, ANSI_NIST *);
extern int substitute_ANSI_NIST_select(const int, const int, const int,
              const int, const char *, ANSI_NIST *);
extern int substitute_ANSI_NIST_record(const int, const char *, ANSI_NIST *);
extern int substitute_ANSI_NIST_field(const int, const int, const char *,
              ANSI_NIST *);
extern int substitute_ANSI_NIST_subfield(const int, const int, const int,
              const char *, ANSI_NIST *);
extern int substitute_ANSI_NIST_item(const int, const int, const int,
              const int, const char *, ANSI_NIST *);

/***********************************************************************/
/* TO_IAFIS.C : ANSI/NIST 2000 TO FBI/IAFIS CONVERSION ROUTINES */
extern int nist2iafis_fingerprints(ANSI_NIST *);
extern int nist2iafis_fingerprint(RECORD **, RECORD *);
extern int nist2iafis_type_9s(ANSI_NIST *);
extern int nist2iafis_needed(RECORD *);
extern int nist2iafis_type_9(RECORD **, ANSI_NIST *, const int);
extern int nist2iafis_method(char **, char *);
extern int nist2iafis_minutia_type(char **, char *);
extern int nist2iafis_pattern_class(char **, char *, const int);
extern int nist2iafis_ridgecount(char **, char *);

/***********************************************************************/
/* TO_NIST.C : FBI/IAFIS TO ANSI/NIST 2000 CONVERSION ROUTINES */
extern int iafis2nist_fingerprints(ANSI_NIST *);
extern int iafis2nist_fingerprint(RECORD **, ANSI_NIST *, const int);
extern int iafis2nist_type_9s(ANSI_NIST *);
extern int iafis2nist_needed(RECORD *);
extern int iafis2nist_type_9(RECORD **, ANSI_NIST *, const int);
extern int iafis2nist_method(char **, char *);
extern int iafis2nist_minutia_type(char **, char *);
extern int iafis2nist_pattern_class(char **, char *, const int);
extern int iafis2nist_ridgecount(char **, char *);

/***********************************************************************/
/* TYPE.C : RECORD & FIELD TYPE TESTS */
extern int tagged_record(const unsigned int);
extern int binary_record(const unsigned int);
extern int tagged_image_record(const unsigned int);
extern int binary_image_record(const unsigned int);
extern int image_record(const unsigned int);
extern int binary_signature_record(const unsigned int);
extern int image_field(const FIELD *);
extern int is_delimeter(const int);
extern int which_hand(const int);

/***********************************************************************/
/* TYPE1314.C : Type-13 and Type-14 ROUTINES */
extern int fingerprint2tagged_field_image(RECORD **, unsigned char *,
                  const int, const int, const int, const int, const double,
                  char *, const int, const int, char *);
extern int image2type_13(RECORD **, unsigned char *, const int, const int,
                  const int, const int, const double, char *, const int,
                  const int, char *);
extern int image2type_14(RECORD **, unsigned char *, const int, const int,
                  const int, const int, const double, char *, const int,
                  const int, char *);

/***********************************************************************/
/* UPDATE.C : UPDATE ROUTINES */
extern int update_ANSI_NIST(ANSI_NIST *, RECORD *);
extern int update_ANSI_NIST_record(RECORD *, FIELD *);
extern int update_ANSI_NIST_field(FIELD *, SUBFIELD *);
extern int update_ANSI_NIST_subfield(SUBFIELD *, ITEM *);
extern int update_ANSI_NIST_item(ITEM *, const int);
extern int update_ANSI_NIST_record_LENs(ANSI_NIST *);
extern int update_ANSI_NIST_record_LEN(ANSI_NIST *, const int);
extern void update_ANSI_NIST_field_ID(FIELD *, const int, const int);

/***********************************************************************/
/* UTIL.C : UTILITY ROUTINES */
extern int increment_numeric_item(const int, const int, const int,
              const int, ANSI_NIST *, char *);
extern int decrement_numeric_item(const int, const int, const int,
              const int, ANSI_NIST *, char *);

/***********************************************************************/
/* VALUE2.C : STRING TO STRUCTURE ROUTINES */
extern int value2field(FIELD **, const int, const int, const char *);
extern int value2subfield(SUBFIELD **, const char *);
extern int value2item(ITEM **, const char *);

#endif /* !_AN2k_H */
