# **********************************************************
# Project:		NIST Fingerprint Software
# SubTree:		./nfs/src/bin/dwsq
# Filename:		makefile.mak
# Integrators:		Craig Watson
#                       Michael Garris
# Organization:		NIST/ITL
# Host System:		GNU GCC/GMAKE GENERIC (UNIX)
# Date Created:		11/24/1999
#
# **********************************************************
# Makefile for SRC Binary Directory
# **********************************************************
SHELL=/bin/sh
# PROJDIR Passed On Command Line ONLY
PROJECT_ROOT	= $(PROJDIR)
LIBDIR		= $(PROJECT_ROOT)/lib

# **************************************************
# INDIVIDUAL PROGRAM MODIFICATIONS SHOULD BEGIN HERE
# **************************************************

# Program to make (binary name)
EXECUTABLE	= dwsq
# Source files for EXECUTABLE
SRC	= dwsq.c
# LIBS needed to compile the EXECUTABLE
# (Full paths eg: /usr/local/image/lib/libimage.a)
# use $(LIBDIR) defined above for path extensions if appropriate
LIBS	= $(LIBDIR)/libimage.a $(LIBDIR)/libihead.a $(LIBDIR)/libwsq.a \
	$(LIBDIR)/libjpegl.a $(LIBDIR)/libfet.a $(LIBDIR)/libioutil.a \
	$(LIBDIR)/libutil.a

# How the libraries look when invoked on the compile line (eg: -limage)
LLIBS	= -limage -lihead -lwsq -ljpegl -lfet -lioutil -lutil -lm

# *******************************************************
# THE REST OF THE MAKEFILE SHOULD NOT NEED TO BE MODIFIED
#       (EXCEPT UPON APPROVAL OF PROJECT MANAGER)
# *******************************************************

EXEFILE	= $(EXECUTABLE)$(EXEEXT)
BIN	= $(PROJECT_ROOT)/bin
OBJ	= $(SRC:.c=.o)
INCLUDE = $(PROJECT_ROOT)/include

CC	= gcc -ansi
CFLAGS	= -O2
CDEFS	= 
CCC	= $(CC) $(CFLAGS) $(CDEFS) -I$(INCLUDE) -L$(LIBDIR)

MAKEFILE	= makefile.mak
.PRECIOUS: $(MAKEFILE)

.c.o:
	$(CCC) -c $<

it: $(EXEFILE)

install: $(MAKEFILE) $(BIN)/$(EXEFILE)
$(BIN)/$(EXEFILE): $(EXEFILE)
	cp $(EXEFILE) $(BIN)
	chmod 755 $(BIN)/$(EXEFILE)
	-strip $(BIN)/$(EXEFILE)

$(EXEFILE): $(OBJ) $(LIBS)
	$(CCC) $(OBJ) $(LLIBS) -o $(EXEFILE)

# if there are other separate programs to compile, add the name to
#	SRC, OBJ, ... and the redo the last 3 lines EXPLICITLY
#	for each program.
#	Install will also have to be changed.

clean :
	rm -f $(OBJ) core a.out *.BAK *~ #*# dependlist

bare: clean
	rm -f $(EXEFILE)

$(MAKEFILE): $(SRC)
	$(CCC) -M $(SRC) > dependlist
	@sed -e '1,/^# DO NOT DELETE/!d' $(MAKEFILE) > $(MAKEFILE).tmp.$$$$; \
	cat dependlist >> $(MAKEFILE).tmp.$$$$; \
	cp $(MAKEFILE) $(MAKEFILE).BAK; \
	mv $(MAKEFILE).tmp.$$$$ $(MAKEFILE); \
	rm -f dependlist

depend: $(SRC)
	$(CCC) -M $(SRC) > dependlist
	@sed -e '1,/^# DO NOT DELETE/!d' $(MAKEFILE) > $(MAKEFILE).tmp.$$$$; \
	cat dependlist >> $(MAKEFILE).tmp.$$$$; \
	cp $(MAKEFILE) $(MAKEFILE).BAK; \
	mv $(MAKEFILE).tmp.$$$$ $(MAKEFILE); \
	rm -f dependlist; \
	echo make depend complete

# DO NOT DELETE THIS LINE - make depend uses it
dwsq.o: dwsq.c /usr/include/stdio.h /usr/include/features.h \
  /usr/include/sys/cdefs.h /usr/include/gnu/stubs.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stddef.h \
  /usr/include/bits/types.h /usr/include/libio.h /usr/include/_G_config.h \
  /usr/include/wchar.h /usr/include/bits/wchar.h /usr/include/gconv.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stdarg.h \
  /usr/include/bits/stdio_lim.h /usr/include/bits/stdio.h \
  /usr/include/sys/param.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/limits.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/syslimits.h \
  /usr/include/limits.h /usr/include/linux/limits.h \
  /usr/include/linux/param.h /usr/include/asm/param.h \
  /usr/include/sys/types.h /usr/include/time.h /usr/include/endian.h \
  /usr/include/bits/endian.h /usr/include/sys/select.h \
  /usr/include/bits/select.h /usr/include/bits/sigset.h \
  /usr/include/bits/time.h /usr/include/sys/sysmacros.h \
  /gig0/craig/sd29/src/include/wsq.h /gig0/craig/sd29/src/include/ihead.h \
  /gig0/craig/sd29/src/include/jpegl.h \
  /gig0/craig/sd29/src/include/nistcom.h \
  /gig0/craig/sd29/src/include/fet.h \
  /gig0/craig/sd29/src/include/img_io.h
