/***********************************************************************
      LIBRARY: IMAGE - Image Manipulation and Processing Routines

      FILE:    COPY.C

      AUTHORS: Michael Garris
               Stan Janet
      DATE:    12/13/1990

      Contains routines responsible for copying a specified subimage
      of a binary image bitmap.

      ROUTINES:
#cat: copy_logical_image - uses a logical operator to copy a binary subimage
#cat:                      into a destination image at a specified location.
#cat: copy_image - copyies a binary subimage into a destination image at a
#cat:              specified location.

***********************************************************************/

/* LINTLIBRARY */

/************************************************************/
/*         Modified 12/13/90 by Stan Janet to call          */
/*                    binary_subimage_{copy,or}().          */
/*         Modified 12/21/90 by Stan Janet to call          */
/*                    binary_subimage_{and,xor}().          */
/************************************************************/

#include <stdio.h>
#include <memory.h>
#include <masks.h>
#include <bits.h>
#include <copy.h>

/************************************************************/
/*         Routine:   Copy_Logical_Image()                  */
/*         Author:    Michael D. Garris                     */
/************************************************************/
/* Copy_logical_image() takes a source image region and     */
/* logically copies it to a destination image region.       */
/* NOTE: x-coords and widths are in bit units.              */
/************************************************************/

void copy_logical_image(logop,
	frdata,frx,fry,frw,frh,
	todata,tox,toy,tow,toh,cpw,cph)
int logop,frx,fry,tox,toy,cpw,cph;
unsigned char *frdata, *todata;
int frw,frh,tow,toh;
{
unsigned char *frptr, *toptr;
int frleftbyteoffset, toleftbyteoffset;
int frleftbitindex, toleftbitindex, frrightbitindex;
int bw;
int leftx,lefty,leftw,lefth,rightx,righty,rightw,righth;

switch (logop) {
  case LOG_COPY:
	binary_subimage_copy(	frdata,frw,frh,
				todata,tow,toh,
				frx,fry,cpw,cph,tox,toy);
	break;
  case LOG_OR:
	binary_subimage_or(	frdata,frw,frh,
				todata,tow,toh,
				frx,fry,cpw,cph,tox,toy);
	break;
  case LOG_AND:
	binary_subimage_and(	frdata,frw,frh,
				todata,tow,toh,
				frx,fry,cpw,cph,tox,toy);
	break;
  case LOG_XOR:
	binary_subimage_xor(	frdata,frw,frh,
				todata,tow,toh,
				frx,fry,cpw,cph,tox,toy);
	break;
  default:
	fatalerr("copy_logical_image","bad operator",(char *)NULL);
	break;
}
}

/************************************************************/
/*         Routine:   Copy_Image()                          */
/*         Author:    Michael D. Garris                     */
/*         Date:      4/30/90                               */
/************************************************************/
/* Copy_image() takes a source image region and copies it to*/
/* a destination image region.                              */
/* NOTE: x-coords and widths are in bit units.              */
/************************************************************/

void copy_image(frdata,frx,fry,frw,frh,todata,tox,toy,tow,toh,cpw,cph)
int frx,fry,tox,toy,cpw,cph;
unsigned char *frdata, *todata;
int frw,frh,tow,toh;
{
unsigned char *frptr, *toptr;
int frleftbyteoffset, toleftbyteoffset;
int frleftbitindex, toleftbitindex, frrightbitindex;
int bw;
int leftx,lefty,leftw,lefth,rightx,righty,rightw,righth;

binary_subimage_copy(	frdata,frw,frh,
			todata,tow,toh,
			frx,fry,cpw,cph,tox,toy);
}
