/***********************************************************************
      LIBRARY: IOUTIL - INPUT/OUTPUT Utilities

      FILE:    FILESIZE.C
      AUTHOR:  Michael Garris
      DATE:    12/05/2001

      Contains routines responsible for determining the size of
      a file in bytes given its path name.

      ROUTINES:
#cat: filesize - opens the specified pathname and determines the size of
#cat:            of the file in bytes.

***********************************************************************/

#include <stdio.h>
#include <unistd.h>

/**********************************************************************/
int filesize(char *ifile)
{
   FILE *fp;
   int ret;

   /* Open file. */
   if((fp = fopen(ifile, "rb")) == (FILE *)NULL){
      fprintf(stderr, "ERROR : filesize : file %s could not be opened\n",
              ifile);
      return(-2);
   }

   /* Move file pointer to end of file. */
   if(fseek(fp, 0, SEEK_END)){
      fprintf(stderr, "ERROR : filesize : seeking to EOF of file %s failed\n",
              ifile);
      return(-3);
   }

   /* Get byte offest to end of file. */
   if((ret = ftell(fp)) < 0){
      fprintf(stderr, "ERROR : filesize : ftell at EOF of file %s failed\n",
              ifile);
      return(-4);
   }

   /* Close file. */
   fclose(fp);

   /* Return size of file in bytes. */
   return(ret);
}
