# **********************************************************
# Project:		NIST Fingerprint Software
# SubTree:		./nfs/src/lib/wsq
# Filename:		makefile.mak
# Integrators:		Michael Garris
#                       Craig Watson
# Organization:		NIST/ITL
# Host System:		GNU GCC/GMAKE GENERIC (UNIX)
# Date Created:		03/16/2001
#
# **********************************************************
# Makefile for SRC Library Directory
# **********************************************************
SHELL=/bin/sh
# PROJDIR Passed On Command Line ONLY
PROJECT_ROOT	= $(PROJDIR)
LIBDIR		= $(PROJECT_ROOT)/lib
SRCDIR		= $(PROJECT_ROOT)/src/lib/wsq

# **************************************************
# INDIVIDUAL PROGRAM MODIFICATIONS SHOULD BEGIN HERE
# **************************************************

# Library to make (library name)
LIBRARY	= libwsq.a
# Source files for LIBRARY
SRC	= decoder.c \
	encoder.c \
	globals.c \
	huff.c \
	ppi.c \
	tableio.c \
	tree.c \
	sd14util.c \
	util.c

# *******************************************************
# THE REST OF THE MAKEFILE SHOULD NOT NEED TO BE MODIFIED
#       (EXCEPT UPON APPROVAL OF PROJECT MANAGER)
# *******************************************************

INCLUDE = $(PROJECT_ROOT)/include
OBJ     = $(SRC:.c=.o)
LIBRY   = $(LIBRARY)

# DEFINES COMPILER AND ANY ANSI FLAGS
CC	= gcc -ansi
# DEFINES COMPILER FLAGS INCLUDING DEBUG (-g) OR OPTIMIZATION LEVEL
CFLAGS	= -O2
# DEFINES CONSTANT DEFINITIONS
CDEFS	=
CCC	= $(CC) $(CFLAGS) $(CDEFS) -I$(INCLUDE) -L$(LIBDIR)

ARFLAGS = ru
AR	= ar $(ARFLAGS)

MAKEFILE	= makefile.mak
.PRECIOUS: $(MAKEFILE)

.c.o:
	$(CCC) -c $<

it: $(LIBRY)

install: $(MAKEFILE) $(LIBDIR)/$(LIBRARY)
$(LIBDIR)/$(LIBRARY): $(LIBRY)
	cp $(LIBRY) $(LIBDIR)
	chmod 644 $(LIBDIR)/$(LIBRARY)
	-ranlib $(LIBDIR)/$(LIBRARY)
	@/bin/sh $(PROJECT_ROOT)/bin/catalog.sh \
		proc $(SRCDIR) c > /dev/null 2>&1

$(LIBRY): $(OBJ)
	$(AR) $(LIBRY) $?
	-ranlib $(LIBRY)

%.o: %.c
	$(CCC) -c -o $@ $<

clean :
	rm -f $(OBJ) *.BAK *~ #*# dependlist;

bare: clean
	rm -f $(LIBRY)

$(MAKEFILE): $(SRC)
	$(CCC) -M $(SRC) > dependlist
	@sed -e '1,/^# DO NOT DELETE/!d' $(MAKEFILE) > $(MAKEFILE).tmp.$$$$; \
	cat dependlist >> $(MAKEFILE).tmp.$$$$; \
	cp $(MAKEFILE) $(MAKEFILE).BAK; \
	mv $(MAKEFILE).tmp.$$$$ $(MAKEFILE); \
	rm -f dependlist

depend: $(SRC)
	$(CCC) -M $(SRC) > dependlist
	@sed -e '1,/^# DO NOT DELETE/!d' $(MAKEFILE) > $(MAKEFILE).tmp.$$$$; \
	cat dependlist >> $(MAKEFILE).tmp.$$$$; \
	cp $(MAKEFILE) $(MAKEFILE).BAK; \
	mv $(MAKEFILE).tmp.$$$$ $(MAKEFILE); \
	rm -f dependlist; \
	echo make depend complete

# DO NOT DELETE THIS LINE - make depend uses it
decoder.o: decoder.c /usr/include/stdio.h /usr/include/features.h \
  /usr/include/sys/cdefs.h /usr/include/gnu/stubs.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stddef.h \
  /usr/include/bits/types.h /usr/include/libio.h /usr/include/_G_config.h \
  /usr/include/wchar.h /usr/include/bits/wchar.h /usr/include/gconv.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stdarg.h \
  /usr/include/bits/stdio_lim.h /usr/include/bits/stdio.h \
  /gig0/craig/sd29/src/include/wsq.h /gig0/craig/sd29/src/include/ihead.h \
  /gig0/craig/sd29/src/include/jpegl.h \
  /gig0/craig/sd29/src/include/nistcom.h \
  /gig0/craig/sd29/src/include/fet.h \
  /gig0/craig/sd29/src/include/dataio.h
encoder.o: encoder.c /usr/include/stdio.h /usr/include/features.h \
  /usr/include/sys/cdefs.h /usr/include/gnu/stubs.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stddef.h \
  /usr/include/bits/types.h /usr/include/libio.h /usr/include/_G_config.h \
  /usr/include/wchar.h /usr/include/bits/wchar.h /usr/include/gconv.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stdarg.h \
  /usr/include/bits/stdio_lim.h /usr/include/bits/stdio.h \
  /gig0/craig/sd29/src/include/wsq.h /gig0/craig/sd29/src/include/ihead.h \
  /gig0/craig/sd29/src/include/jpegl.h \
  /gig0/craig/sd29/src/include/nistcom.h \
  /gig0/craig/sd29/src/include/fet.h \
  /gig0/craig/sd29/src/include/dataio.h
globals.o: globals.c /gig0/craig/sd29/src/include/wsq.h \
  /usr/include/stdio.h /usr/include/features.h /usr/include/sys/cdefs.h \
  /usr/include/gnu/stubs.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stddef.h \
  /usr/include/bits/types.h /usr/include/libio.h /usr/include/_G_config.h \
  /usr/include/wchar.h /usr/include/bits/wchar.h /usr/include/gconv.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stdarg.h \
  /usr/include/bits/stdio_lim.h /usr/include/bits/stdio.h \
  /gig0/craig/sd29/src/include/ihead.h \
  /gig0/craig/sd29/src/include/jpegl.h \
  /gig0/craig/sd29/src/include/nistcom.h \
  /gig0/craig/sd29/src/include/fet.h
huff.o: huff.c /usr/include/stdio.h /usr/include/features.h \
  /usr/include/sys/cdefs.h /usr/include/gnu/stubs.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stddef.h \
  /usr/include/bits/types.h /usr/include/libio.h /usr/include/_G_config.h \
  /usr/include/wchar.h /usr/include/bits/wchar.h /usr/include/gconv.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stdarg.h \
  /usr/include/bits/stdio_lim.h /usr/include/bits/stdio.h \
  /gig0/craig/sd29/src/include/wsq.h /gig0/craig/sd29/src/include/ihead.h \
  /gig0/craig/sd29/src/include/jpegl.h \
  /gig0/craig/sd29/src/include/nistcom.h \
  /gig0/craig/sd29/src/include/fet.h
ppi.o: ppi.c /usr/include/stdio.h /usr/include/features.h \
  /usr/include/sys/cdefs.h /usr/include/gnu/stubs.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stddef.h \
  /usr/include/bits/types.h /usr/include/libio.h /usr/include/_G_config.h \
  /usr/include/wchar.h /usr/include/bits/wchar.h /usr/include/gconv.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stdarg.h \
  /usr/include/bits/stdio_lim.h /usr/include/bits/stdio.h \
  /gig0/craig/sd29/src/include/wsq.h /gig0/craig/sd29/src/include/ihead.h \
  /gig0/craig/sd29/src/include/jpegl.h \
  /gig0/craig/sd29/src/include/nistcom.h \
  /gig0/craig/sd29/src/include/fet.h
tableio.o: tableio.c /usr/include/stdio.h /usr/include/features.h \
  /usr/include/sys/cdefs.h /usr/include/gnu/stubs.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stddef.h \
  /usr/include/bits/types.h /usr/include/libio.h /usr/include/_G_config.h \
  /usr/include/wchar.h /usr/include/bits/wchar.h /usr/include/gconv.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stdarg.h \
  /usr/include/bits/stdio_lim.h /usr/include/bits/stdio.h \
  /gig0/craig/sd29/src/include/wsq.h /gig0/craig/sd29/src/include/ihead.h \
  /gig0/craig/sd29/src/include/jpegl.h \
  /gig0/craig/sd29/src/include/nistcom.h \
  /gig0/craig/sd29/src/include/fet.h \
  /gig0/craig/sd29/src/include/dataio.h \
  /gig0/craig/sd29/src/include/swap.h /gig0/craig/sd29/src/include/defs.h
tree.o: tree.c /usr/include/stdio.h /usr/include/features.h \
  /usr/include/sys/cdefs.h /usr/include/gnu/stubs.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stddef.h \
  /usr/include/bits/types.h /usr/include/libio.h /usr/include/_G_config.h \
  /usr/include/wchar.h /usr/include/bits/wchar.h /usr/include/gconv.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stdarg.h \
  /usr/include/bits/stdio_lim.h /usr/include/bits/stdio.h \
  /gig0/craig/sd29/src/include/wsq.h /gig0/craig/sd29/src/include/ihead.h \
  /gig0/craig/sd29/src/include/jpegl.h \
  /gig0/craig/sd29/src/include/nistcom.h \
  /gig0/craig/sd29/src/include/fet.h
sd14util.o: sd14util.c /usr/include/stdio.h /usr/include/features.h \
  /usr/include/sys/cdefs.h /usr/include/gnu/stubs.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stddef.h \
  /usr/include/bits/types.h /usr/include/libio.h /usr/include/_G_config.h \
  /usr/include/wchar.h /usr/include/bits/wchar.h /usr/include/gconv.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stdarg.h \
  /usr/include/bits/stdio_lim.h /usr/include/bits/stdio.h \
  /gig0/craig/sd29/src/include/wsq.h /gig0/craig/sd29/src/include/ihead.h \
  /gig0/craig/sd29/src/include/jpegl.h \
  /gig0/craig/sd29/src/include/nistcom.h \
  /gig0/craig/sd29/src/include/fet.h \
  /gig0/craig/sd29/src/include/dataio.h
util.o: util.c /usr/include/math.h /usr/include/features.h \
  /usr/include/sys/cdefs.h /usr/include/gnu/stubs.h \
  /usr/include/bits/huge_val.h /usr/include/bits/mathdef.h \
  /usr/include/bits/mathcalls.h /usr/include/bits/mathinline.h \
  /usr/include/stdio.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stddef.h \
  /usr/include/bits/types.h /usr/include/libio.h /usr/include/_G_config.h \
  /usr/include/wchar.h /usr/include/bits/wchar.h /usr/include/gconv.h \
  /usr/lib/gcc-lib/i386-redhat-linux/2.96/include/stdarg.h \
  /usr/include/bits/stdio_lim.h /usr/include/bits/stdio.h \
  /gig0/craig/sd29/src/include/wsq.h /gig0/craig/sd29/src/include/ihead.h \
  /gig0/craig/sd29/src/include/jpegl.h \
  /gig0/craig/sd29/src/include/nistcom.h \
  /gig0/craig/sd29/src/include/fet.h /gig0/craig/sd29/src/include/defs.h
